@@ -1,7 +1,6 @@
+"""sscu-budapest utilities for scientific data engineering"""
 # flake8: noqa
 from ._version import __version__
-from .artifact_context import dump_dfs_to_tables, run_step
-from .invoke_commands import ns
 from .metadata.datascript import (
     BaseEntity,
     CompositeTypeBase,
@@ -11,4 +10,8 @@ from .metadata.datascript import (
 )
 from .metadata.datascript.scrutable import ScruTable
 from .pipeline_registry import register, register_data_loader, register_env_creator
+from .project_runtime import dump_dfs_to_tables
 from .reporting import ReportFile
+from .typer_commands import app
+
+__version__ = "0.2.2"
