@@ -5,8 +5,7 @@ from functools import partial
 from inspect import ismodule
 from itertools import chain
 from pathlib import Path
-from subprocess import check_output
-from tempfile import TemporaryDirectory
+from subprocess import check_call, check_output
 from typing import List, Type, TypeVar, Union
 
 import isort
@@ -15,7 +14,7 @@ from black.report import NothingChanged
 from sqlalchemy.dialects.postgresql import dialect as postgres_dialect
 from yaml import safe_load
 
-from .naming import MAIN_MODULE_NAME, META_MODULE_NAME, SANDBOX_DIR, template_repo
+from .naming import MAIN_MODULE_NAME, META_MODULE_NAME
 
 LINE_LEN = 119
 PRIMITIVE_MODULES = ["builtins", "datetime"]
@@ -57,61 +56,46 @@ def is_repo(s):
     return any(map(str(s).startswith, ["git@", "http://", "https://"]))
 
 
-@contextmanager
-def cd_into(
-    dirpath: Union[str, Path],
-    reset_src=True,
-    checkout=None,
-    force_clone=False,
-):
-    _run = check_output
+def git_run(add=(), msg=None, pull=False, push=False, wd=None):
+    for k, git_cmd in [
+        (add, ["add", *add]),
+        (msg, ["commit", "-m", msg]),
+        (pull, ["pull"]),
+        (push, ["push"]),
+    ]:
+        if k:
+            check_call(["git", *git_cmd], cwd=wd)
 
+
+def get_git_diffs(staged=False):
+    comm = ["git", "diff", "--name-only"]
+    if staged:
+        comm.append("--cached")
+    diffs = check_output(comm)
+    return [*filter(None, diffs.decode("utf-8").strip().split("\n"))]
+
+
+@contextmanager
+def cd_into(dirpath: Union[str, Path]):
     wd = os.getcwd()
-    needs_clone = force_clone or is_repo(dirpath)
-
-    if needs_clone:
-        tmp_dir = TemporaryDirectory()
-        cd_path = tmp_dir.__enter__()
-        _run(["git", "clone", str(dirpath), "."], cwd=cd_path)
-    else:
-        cd_path = dirpath
-
-    if checkout:
-        _run(["git", "checkout", checkout], cwd=cd_path)
-
-    os.chdir(cd_path)
-    sys.path.insert(0, str(cd_path))
-
-    if reset_src:
-        reset_src_module()
-    yield
-
-    os.chdir(wd)
-    sys.path.pop(0)
-    if needs_clone:
-        tmp_dir.__exit__(None, None, None)
-
-
-@contextmanager
-def sandbox_artifact():
-    if not SANDBOX_DIR.exists():
-        check_output(["git", "clone", template_repo, SANDBOX_DIR.as_posix()])
-    with cd_into(SANDBOX_DIR):
+    os.chdir(dirpath)
+    # sys.path.insert(0, str(dirpath))
+    reset_src_module()
+    try:
         yield
+    finally:
+        os.chdir(wd)
+        # sys.path.pop(0)
 
 
 def format_code(code_str):
     try:
-        blacked = format_file_contents(
-            code_str, fast=True, mode=Mode(line_length=LINE_LEN)
-        )
+        mode = Mode(line_length=LINE_LEN)
+        blacked = format_file_contents(code_str, fast=True, mode=mode)
     except NothingChanged:
         blacked = code_str
 
-    return isort.code(
-        blacked,
-        profile="black",
-    )
+    return isort.code(blacked, profile="black")
 
 
 def load_named_dict_to_list(
